@@ -316,7 +316,7 @@
 /* #undef SDL_AUDIO_DRIVER_PAUDIO */
 #define SDL_AUDIO_DRIVER_PIPEWIRE 1
 /* #undef SDL_AUDIO_DRIVER_PIPEWIRE_DYNAMIC */
-#define SDL_AUDIO_DRIVER_PULSEAUDIO 1
+/* #undef SDL_AUDIO_DRIVER_PULSEAUDIO */
 /* #undef SDL_AUDIO_DRIVER_PULSEAUDIO_DYNAMIC */
 /* #undef SDL_AUDIO_DRIVER_QSA */
 /* #undef SDL_AUDIO_DRIVER_SNDIO */
